@@ -23,7 +23,7 @@ messages about granted attribute access.
 Note that the ZOPE_WATCH_CHECKERS mechanism will eventually be
 replaced with a more general security auditing mechanism.
 
-$Id: checker.py 99938 2009-05-13 22:49:50Z tseaver $
+$Id: checker.py 105559 2009-11-10 14:35:15Z jim $
 """
 import os
 import sys
@@ -727,11 +727,15 @@ _default_checkers = {
     zope.interface.declarations.Declaration: _Declaration_checker,
 }
 
-if sys.version_info[:2] < (2, 6):
+if sys.version_info < (2, 6):
     import sets
     _default_checkers[sets.Set] = _setChecker
     _default_checkers[sets.ImmutableSet] = _setChecker
 
+if sys.version_info >= (2, 6):
+    import abc
+    _default_checkers[abc.ABCMeta] = _typeChecker
+
 
 def _clear():
     _checkers.clear()
